@@ -2,28 +2,35 @@ import pyodbc
 import pandas as pd
 from pandas.io.sql import DatabaseError
 import datetime
+from enum import Enum
+
+class Connector(Enum):
+    Automatic = "Automatic"
+    ServiceEngine = "zenonV6"
+    SQL = "zenonSQL"
+    DataStorage = "ServiceGridDataStorage"
 
 class Server:
-    """This class handles a connection to a zenon Analyzer metadata database and read or writes data."""
+    """This class handles a connection to a Report Engine metadata database and read or writes data."""
 
     def __init__(self, server:str, 
     metadb:str, 
-    analyzer_major_version:int= 3, 
+    analyzer_major_version:int= 11, 
     use_integrated_security:bool = True, 
     user:str = None, 
     password:str = None):
-        """Initializes a new connection to a zenon Analyzer metadata database.
+        """Initializes a new connection to a Report Engine metadata database.
         
         Parameters
         ----------
         server: `string`
-            zenon Analyzer server computer name, e.g. 'localhost'
+            Report Engine server computer name, e.g. 'localhost'
 
         metadb: `string`
-            zenon Analyzer metadata database name, e.g. 'ZA_DATA'
+            zReport Engine metadata database name, e.g. 'ZA_DATA'
 
         analyzer_major_version: `int`
-            zenon Analyzer major version, e.g. 3 for 3.30, 3.40, ...
+            Report Engine major version, e.g. 3 for 3.30, 3.40, ...
 
         use_integrated_security: `bool`
             Connect to the database using current windows credentials 
@@ -36,14 +43,18 @@ class Server:
 
         Examples
         --------   
-        Connect to the local Analyzer metadata database 'REPORTING':
+        Connect to the local Report Engine metadata database 'REPORTING':
 
         >>> zan = Analyzer.Server( server='localhost', metadb='REPORTING')  
         """
 
-        """The minimum zenon Analyzer version is 3.30."""
+        """The minimum zenon Analyzer/Report Engine version is 3.30."""
         if(analyzer_major_version >= 3):
-            self._server = "{0}\ZA{1}".format(server, str(analyzer_major_version))
+            if(analyzer_major_version >= 10):
+                self._server = "{0}\ZA2019".format(server)
+            else:
+                self._server = "{0}\ZA{1}".format(server, str(analyzer_major_version))
+            self._analyzer_major_version = analyzer_major_version
             self._metadb = metadb
             self._useIntegratedSecurity = use_integrated_security
             self._user = user
@@ -60,28 +71,49 @@ class Server:
                 + self._metadb + ";UID="
                 + self._user + ";PWD=" + self._password)
 
-            #Check zenon Analyzer metadata database version. Must be at least version 7 for 3.30
+            #Check Report Engine metadata database version. Must be at least version 7 for 3.30
             try:
                 result = pd.read_sql(
                     f"SELECT [{self._metadb}].[dbo].[zrsGetDatabaseVersion]()", self._cnxn)
                 self._version = result.iloc[0][0]
                 if(self._version < 7):
-                    raise RuntimeError(f"zenon Analyzer metadata database version {str(self._version)} ist not supported")
+                    raise RuntimeError(f"Report Engine metadata database version {str(self._version)} ist not supported")
             except:
-              raise RuntimeError("Unable to check zenon Analyzer metadata database version")              
+              raise RuntimeError("Unable to check Report Engine metadata database version")              
         else:
-           raise RuntimeError(f"Invalid zenon Analyzer major version {analyzer_major_version}! The major version must be 3 or higher.")    
+           raise RuntimeError(f"Invalid Report Enginer major version {analyzer_major_version}! The major version must be 3 or higher.")    
 
 
     def read_MetaData_Archives(self)->pd.DataFrame:
-        """Lists all archives from the connected zenon Analyzer metadata database.
+        """Lists all archives from the connected Report Engine metadata database.
 
         Returns
         --------
-        DataFrame: [ID, PROJECT_ID, REFERENCE, VISUALNAME, DESCRIPTION, CYCLETIME LOTARCHIV, PARENT_ID]
+        version >= 11 --> DataFrame: [ID, PROJECT_ID, REFERENCE, VISUALNAME, DESCRIPTION, CYCLETIME LOTARCHIV, PARENT_ID, DESCRIPTION_TRANSLATABLE]
+        version < 11 --> DataFrame: [ID, PROJECT_ID, REFERENCE, VISUALNAME, DESCRIPTION, CYCLETIME LOTARCHIV, PARENT_ID]
         """ 
 
-        sqlCmd = f"SELECT [ID],[PROJECT_ID],[REFERENCE],[VISUALNAME],[DESCRIPTION],[CYCLETIME],[LOTARCHIV],[PARENT_ID] FROM [{self._metadb}].[dbo].[ARCHIV]"
+        if(self._analyzer_major_version < 11):
+            sqlCmd = f"""SELECT [ID],
+                      [PROJECT_ID],
+                      [REFERENCE],
+                      [VISUALNAME],
+                      [DESCRIPTION],
+                      [CYCLETIME],
+                      [LOTARCHIV],
+                      [PARENT_ID]                     
+                      FROM [{self._metadb}].[dbo].[ARCHIV]"""
+        else:
+            sqlCmd = f"""SELECT [ID],
+                        [PROJECT_ID],
+                        [REFERENCE],
+                        [VISUALNAME],
+                        [DESCRIPTION],
+                        [CYCLETIME],
+                        [LOTARCHIV],
+                        [PARENT_ID],
+                        [DESCRIPTION_TRANSLATABLE]
+                        FROM [{self._metadb}].[dbo].[ARCHIV]"""
         try:
             return pd.read_sql(sqlCmd, self._cnxn)
         except:
@@ -89,14 +121,18 @@ class Server:
 
 
     def read_MetaData_Equipments(self)->pd.DataFrame:
-        """Lists all equipment groups from the connected zenon Analyzer metadata database.
+        """Lists all equipment groups from the connected Report Engine metadata database.
 
         Returns
         --------
-        DataFrame: [ID, REFERENCE, VISUALNAME, DESCRIPTION, NESTINGLEVEL, PARENT_ID, MODEL_ID]
+        version >= 11 --> DataFrame: [ID, REFERENCE, VISUALNAME, DESCRIPTION, NESTINGLEVEL, PARENT_ID, MODEL_ID, VISUALNAME_TRANSLATABLE, DESCRIPTION_TRANSLATABLE]
+        version < 11 --> DataFrame: [ID, REFERENCE, VISUALNAME, DESCRIPTION, NESTINGLEVEL, PARENT_ID, MODEL_ID]
         """   
-
-        sqlCmd = f"SELECT [ID],[REFERENCE],[VISUALNAME],[DESCRIPTION],[NESTINGLEVEL],[PARENT_ID],[MODEL_ID] FROM [{self._metadb}].[dbo].[EQUIPMENT]"
+        
+        if(self._analyzer_major_version < 11):
+            sqlCmd = f"SELECT [ID],[REFERENCE],[VISUALNAME],[DESCRIPTION],[NESTINGLEVEL],[PARENT_ID],[MODEL_ID] FROM [{self._metadb}].[dbo].[EQUIPMENT]"
+        else:
+            sqlCmd = f"SELECT [ID],[REFERENCE],[VISUALNAME],[DESCRIPTION],[NESTINGLEVEL],[PARENT_ID],[MODEL_ID],[VISUALNAME_TRANSLATABLE],[DESCRIPTION_TRANSLATABLE] FROM [{self._metadb}].[dbo].[EQUIPMENT]"
         try:
             return pd.read_sql(sqlCmd, self._cnxn)
         except:
@@ -104,14 +140,28 @@ class Server:
 
 
     def read_MetaData_Projects(self)->pd.DataFrame:
-        """Lists all projects from the connected zenon Analyzer metadata database.
+        """Lists all projects from the connected Report Engine metadata database.
 
         Returns
         --------
-        DataFrame: [ID, REFERENCE, VISUALNAME, DESCRIPTION]
+        version >= 11 --> DataFrame: [ID, REFERENCE, VISUALNAME, DESCRIPTION, SERVER, STANDBY]
+        version < 11 --> DataFrame: [ID, REFERENCE, VISUALNAME, DESCRIPTION]
         """  
 
-        sqlCmd = f"SELECT [ID],[REFERENCE],[VISUALNAME],[DESCRIPTION] FROM [{self._metadb}].[dbo].[PROJECT]"
+        if(self._analyzer_major_version < 11):
+            sqlCmd = f"""SELECT [ID],
+                        [REFERENCE],
+                        [VISUALNAME],
+                        [DESCRIPTION]                       
+                        FROM [{self._metadb}].[dbo].[PROJECT]"""
+        else:
+            sqlCmd = f"""SELECT [ID],
+                    [REFERENCE],
+                    [VISUALNAME],
+                    [DESCRIPTION],
+                    [SERVER],
+                    [STANDBY]
+                    FROM [{self._metadb}].[dbo].[PROJECT]"""
         try:
             return pd.read_sql(sqlCmd, self._cnxn)
         except:
@@ -119,21 +169,44 @@ class Server:
 
 
     def read_MetaData_Variables(self)->pd.DataFrame:
-        """Lists all variables from the connected zenon Analyzer metadata database.
+        """Lists all variables from the connected Report Engine metadata database.
 
         Returns
         --------
-        DataFrame: [ID, PROJECT_ID, REFERENCE, VISUALNAME, DESCRIPTION, MEANINGS, UNIT]
+        version >= 11 --> DataFrame: [ID, PROJECT_ID, REFERENCE, VISUALNAME, DESCRIPTION, MEANING, UNIT, VISUALNAME_TRANSLATABLE, DESCRIPTION_TRANSLATABLE, UNIT_TRANSLATABLE]
+        version < 11 --> DataFrame: [ID, PROJECT_ID, REFERENCE, VISUALNAME, DESCRIPTION, MEANING, UNIT]
         """  
-
-        sqlCmd = f"SELECT [ID],[PROJECT_ID],[REFERENCE],[VISUALNAME],[DESCRIPTION],[MEANING],[UNIT] FROM [{self._metadb}].[dbo].[VARIABLE]"
+        if(self._analyzer_major_version < 11):
+            sqlCmd = f"""SELECT [ID],
+                        [PROJECT_ID],
+                        [REFERENCE],
+                        [VISUALNAME],
+                        [DESCRIPTION],
+                        [MEANING],
+                        [UNIT]
+                        FROM [{self._metadb}].[dbo].[VARIABLE]"""
+        else:
+            sqlCmd = f"""SELECT [ID],
+                        [PROJECT_ID],
+                        [REFERENCE],
+                        [VISUALNAME],
+                        [DESCRIPTION],
+                        [MEANING],
+                        [UNIT],
+                        [IMPORT_TAG],
+                        [VISUALNAME_TRANSLATABLE],
+                        [DESCRIPTION_TRANSLATABLE],
+                        [UNIT_TRANSLATABLE],
+                        [RESOURCES_LABEL],
+                        [IDENTIFICATION]
+                        FROM [{self._metadb}].[dbo].[VARIABLE]"""
         try:
             return pd.read_sql(sqlCmd, self._cnxn)
         except:
            raise RuntimeError("Unable to load variables from table")
 
 
-    def read_Metadata_VariablesInArchives(self, archive_references:[]=None, project_references:[]=None)-> pd.DataFrame:
+    def read_Metadata_VariablesInArchives(self, archive_references:list=None, project_references:list=None)-> pd.DataFrame:
         """Lists archive variables filtered by archive and project references.
 
         Parameters
@@ -150,7 +223,8 @@ class Server:
 
         Returns
         --------
-        DataFrame: [ID, PROJECT_ID, REFERENCE, VISUALNAME, DESCRIPTION, MEANINGS, UNIT]
+        version >= 11 --> DataFrame: [ID, PROJECT_ID, REFERENCE, VISUALNAME, DESCRIPTION, MEANING, UNIT, VISUALNAME_TRANSLATABLE, DESCRIPTION_TRANSLATABLE, UNIT_TRANSLATABLE]
+        version < 11 --> DataFrame: [ID, PROJECT_ID, REFERENCE, VISUALNAME, DESCRIPTION, MEANING, UNIT]
         """  
         variables = self.read_MetaData_Variables()
         archives = self.read_MetaData_Archives()
@@ -167,7 +241,7 @@ class Server:
         return variables[variables.ID.isin(ids)]
 
 
-    def read_Metadata_VariablesInEquipmentGroups(self, equipmentgroup_references:[]=None, project_references:[]=None)-> pd.DataFrame:
+    def read_Metadata_VariablesInEquipmentGroups(self, equipmentgroup_references:list=None, project_references:list=None)-> pd.DataFrame:
         """Lists variables linked to the equipment group, filtered by equipment group and project references.
 
         Parameters
@@ -184,7 +258,8 @@ class Server:
 
         Returns
         --------
-        DataFrame: [ID, PROJECT_ID, REFERENCE, VISUALNAME, DESCRIPTION, MEANINGS, UNIT]
+        version >= 11 --> DataFrame: [ID, PROJECT_ID, REFERENCE, VISUALNAME, DESCRIPTION, MEANING, UNIT, VISUALNAME_TRANSLATABLE, DESCRIPTION_TRANSLATABLE, UNIT_TRANSLATABLE]
+        version < 11 --> DataFrame: [ID, PROJECT_ID, REFERENCE, VISUALNAME, DESCRIPTION, MEANING, UNIT]
         """  
         variables = self.read_MetaData_Variables()
 
@@ -201,7 +276,7 @@ class Server:
         return variables[variables.ID.isin(ids)]
 
 
-    def read_Metadata_ArchivesInEquipmentGroups(self, equipmentgroup_references:[]=None, project_references:[]=None)-> pd.DataFrame:
+    def read_Metadata_ArchivesInEquipmentGroups(self, equipmentgroup_references:list=None, project_references:list=None)-> pd.DataFrame:
         """Lists archives linked to the equipment group, filtered by equipment group and project references.
 
         Parameters
@@ -218,7 +293,8 @@ class Server:
 
         Returns
         --------
-        DataFrame: [ID, PROJECT_ID, REFERENCE, VISUALNAME, DESCRIPTION, CYCLETIME, LOTARCHIV, PARENT_ID]
+        version >= 11 --> DataFrame: [ID, PROJECT_ID, REFERENCE, VISUALNAME, DESCRIPTION, CYCLETIME LOTARCHIV, PARENT_ID, DESCRIPTION_TRANSLATABLE]
+        version < 11 --> DataFrame: [ID, PROJECT_ID, REFERENCE, VISUALNAME, DESCRIPTION, CYCLETIME LOTARCHIV, PARENT_ID]
         """  
         archives = self.read_MetaData_Archives()
         equipments = self.read_MetaData_Equipments()
@@ -232,12 +308,12 @@ class Server:
 
         if project_references != None:
             projects = self.read_MetaData_Projects()
-            archives = a[a.PROJECT_ID.isin(p[p.REFERENCE.isin(project_references)].ID)]
+            archives = archives[archives.PROJECT_ID.isin(projects[projects.REFERENCE.isin(project_references)].ID)]
 
         return archives
 
 
-    def read_Metadata_ArchivesInProjects(self, project_references:[]= None)-> pd.DataFrame:
+    def read_Metadata_ArchivesInProjects(self, project_references:list= None)-> pd.DataFrame:
         """Lists archives filtered by project references.
 
         Parameters
@@ -249,7 +325,8 @@ class Server:
 
         Returns
         --------
-        DataFrame: [ID, REFERENCE, VISUALNAME, DESCRIPTION, SERVER, STANDBY]
+        version >= 11 --> DataFrame: [ID, PROJECT_ID, REFERENCE, VISUALNAME, DESCRIPTION, CYCLETIME LOTARCHIV, PARENT_ID, DESCRIPTION_TRANSLATABLE]
+        version < 11 --> DataFrame: [ID, PROJECT_ID, REFERENCE, VISUALNAME, DESCRIPTION, CYCLETIME LOTARCHIV, PARENT_ID]
         """  
         projects = self.read_MetaData_Projects()
 
@@ -261,14 +338,18 @@ class Server:
 
 
     def read_MetaData_EventClasses(self)->pd.DataFrame:
-        """Lists all alarm/event classes from the connected zenon Analyzer metadata database.
+        """Lists all alarm/event classes from the connected Report Engine metadata database.
 
         Returns
         --------
-        DataFrame: [ID, REFERENCE, VISUALNAME, DESCRIPTION]
+        version >= 11 --> DataFrame: [ID, REFERENCE, VISUALNAME, DESCRIPTION, VISUALNAME_TRANSLATABLE, DESCRIPTION_TRANSLATABLE]
+        version < 11 --> DataFrame: [ID, REFERENCE, VISUALNAME, DESCRIPTION]
         """   
-
-        sqlCmd = f"SELECT [ID],[REFERENCE],[VISUALNAME],[DESCRIPTION] FROM [{self._metadb}].[dbo].[EVENTCLASS]"
+        
+        if(self._analyzer_major_version < 11):
+            sqlCmd = f"SELECT [ID],[REFERENCE],[VISUALNAME],[DESCRIPTION] FROM [{self._metadb}].[dbo].[EVENTCLASS]"
+        else:
+            sqlCmd = f"SELECT [ID],[REFERENCE],[VISUALNAME],[DESCRIPTION],[VISUALNAME_TRANSLATABLE],[DESCRIPTION_TRANSLATABLE] FROM [{self._metadb}].[dbo].[EVENTCLASS]"
         try:
             return pd.read_sql(sqlCmd, self._cnxn)
         except:
@@ -276,14 +357,18 @@ class Server:
 
 
     def read_MetaData_EventGroups(self)->pd.DataFrame:
-        """Lists all alarm/event groups from the connected zenon Analyzer metadata database.
+        """Lists all alarm/event groups from the connected Report Engine metadata database.
 
         Returns
         --------
-        DataFrame: [ID, REFERENCE, VISUALNAME, DESCRIPTION]
+        version >= 11 --> DataFrame: [ID, REFERENCE, VISUALNAME, DESCRIPTION, VISUALNAME_TRANSLATABLE, DESCRIPTION_TRANSLATABLE]
+        version < 11 --> DataFrame: [ID, REFERENCE, VISUALNAME, DESCRIPTION]
         """  
-
-        sqlCmd = f"SELECT [ID],[REFERENCE],[VISUALNAME],[DESCRIPTION] FROM [{self._metadb }].[dbo].[EVENTGROUP]"
+        
+        if(self._analyzer_major_version < 11):
+            sqlCmd = f"SELECT [ID],[REFERENCE],[VISUALNAME],[DESCRIPTION] FROM [{self._metadb}].[dbo].[EVENTGROUP]"
+        else:
+            sqlCmd = f"SELECT [ID],[REFERENCE],[VISUALNAME],[DESCRIPTION],[VISUALNAME_TRANSLATABLE],[DESCRIPTION_TRANSLATABLE] FROM [{self._metadb}].[dbo].[EVENTGROUP]"
         try:
             return pd.read_sql(sqlCmd, self._cnxn)
         except:
@@ -291,7 +376,7 @@ class Server:
 
 
     def read_MetaData_Archive_Equipment_Relationship(self)->pd.DataFrame:
-        """Lists all archives assignments to equipment groups from the connected zenon Analyzer metadata database.
+        """Lists all archives assignments to equipment groups from the connected Report Engine metadata database.
 
         Returns
         --------
@@ -306,7 +391,7 @@ class Server:
 
 
     def read_MetaData_Variable_Equipment_Relationship(self)->pd.DataFrame:
-        """Lists all variables assignments to equipment groups from the connected zenon Analyzer metadata database.
+        """Lists all variables assignments to equipment groups from the connected Report Engine metadata database.
 
         Returns
         --------
@@ -321,7 +406,7 @@ class Server:
 
 
     def read_MetaData_Variable_Archive_Relationship(self)->pd.DataFrame:
-        """Lists all variables assignments to archives from the connected zenon Analyzer metadata database.
+        """Lists all variables assignments to archives from the connected Report Engine metadata database.
 
         Returns
         --------
@@ -337,11 +422,11 @@ class Server:
 
     def read_Online_Alarms(self, time_from:datetime, time_to:datetime, 
     project_reference:str = None, 
-    connector:str ="zenonV6", 
+    connector:Enum = Connector.Automatic.value,
     variable_references = [], 
     event_class_references = [],
     event_group_references = [],
-    contextlist_ids  =[],
+    contextlist_ids =[],
     show_visualnames:bool = False
     )->pd.DataFrame: 
         """Lists all active alarm items of the selected project. 
@@ -362,8 +447,8 @@ class Server:
             Reference of the project from which the alarms should be read.
             To get the project reference use the function 'read_MetaData_Projects'.
 
-        connector: `string`
-            zenon Connectors: 'zenonV6' or 'zenonSQL'
+        connector: `Enum`
+            zenon Connectors: 'ServiceEngine', 'SQL', 'ServiceGridDataStorage', 'Automatic'
 
         variable_references: `list`
             Filter for variable references. 
@@ -416,7 +501,8 @@ class Server:
         >>> time_to = datetime(year=2019, month=11, day=14, hour=10, minute=30)
         >>> time_from = time_to - timedelta(hours=3)
         >>> alarms = zan.read_Online_Alarms(time_from = time_from, time_to = time_to,project_reference='ZAD_GBL')
-        """  
+        """
+        self._check_Connector(connector)
 
         variables = self._convert_list_To_String(variable_references)
         event_classes = self._convert_list_To_String(event_class_references)
@@ -424,16 +510,16 @@ class Server:
         contextlist = self._convert_list_To_String(contextlist_ids)
         try:
             if not  show_visualnames:
-                sqlCmd = f""""SELECT * FROM [{self._metadb}].[dbo].[zrsQueryAlarmEx2Function](
+                sqlCmd = f"""SELECT * FROM [{self._metadb}].[dbo].[zrsQueryAlarmEx2Function](
                         '{self._metadb}',
-                        '{self.project_reference}',
-                        '{self.connector}',
-                        '{self.variables}',
-                        '{self.event_classes}',
-                        '{self.event_groups}',
-                        '{self.contextlist}',
+                        '{project_reference}',
+                        '{connector}',
+                        '{variables}',
+                        '{event_classes}',
+                        '{event_groups}',
+                        '{contextlist}',
                         '{time_from.strftime('%Y-%m-%d %H:%M:%S')}',
-                        '{time_from.strftime('%Y-%m-%d %H:%M:%S')})'"""
+                        '{time_to.strftime('%Y-%m-%d %H:%M:%S')}')"""
             else:
                 sqlCmd=f"""SELECT va.[VISUALNAME] as VARIABLE_NAME, 
                             al.[LIMIT], 
@@ -480,9 +566,9 @@ class Server:
     def read_Online_Archive(self, time_from:datetime, time_to:datetime, 
     project_reference:str = None, 
     archive_reference:str = None, 
-    connector:str ="zenonV6", 
+    connector:Enum = Connector.Automatic.value,
     variable_references = [], 
-    archive_aggregation:int = 0,
+    archive_aggregation:int = -1,
     show_visualnames:bool = False
     )->pd.DataFrame: 
         """Lists archive data of the selected project and archive from Runtime. 
@@ -507,8 +593,8 @@ class Server:
             Reference of the archive from which the archive data should be read.
             To get the archive reference use the function 'read_MetaData_Archives'.
 
-        connector: `string`
-            zenon connectors: 'zenonV6' or 'zenonSQL'
+        connector: `Enum`
+            zenon Connectors: 'ServiceEngine', 'SQL', 'ServiceGridDataStorage', 'Automatic'
 
         variable_references: `list`
             Filter for variable references. 
@@ -550,11 +636,14 @@ class Server:
         >>> archive_data = zan.read_Online_Archive(time_from = time_from, time_to = time_to,project_name='ZAD_GBL',archive_reference='5A')
         """
 
+        self._check_Connector(connector)
+
         if(archive_aggregation not in range(-1, 5)):
             raise RuntimeError(f"The archive_aggregation '{str(archive_aggregation)}' is out of range!")
 
         variables = self._convert_list_To_String(variable_references)
         try:
+            # Report Engine database has version 8 or higher. Here filtering on calcualtion type is directly possible
             if(self._version >= 8):
                 if not  show_visualnames:
                     sqlCmd = f"""SELECT * FROM [{self._metadb}].[dbo].[zrsQueryArchiveExFunction](
@@ -639,7 +728,7 @@ class Server:
                                     JOIN [{self._metadb}].[dbo].[VARIABLE] va ON va.[ID] = ar.[VARIABLE_ID]
                                     WHERE [CALCULATION] = {str(archive_aggregation)}"""               
             else:
-                raise RuntimeError(f"Unsupported Analyzer metadata database version {str(self._version)}!")
+                raise RuntimeError(f"Unsupported Report Engine metadata database version {str(self._version)}!")
                             
             return pd.read_sql(sqlCmd, self._cnxn)
 
@@ -651,11 +740,11 @@ class Server:
 
     def read_Online_Current_Variables_Value(self, 
     project_reference:str = None, 
-    connector:str ="zenonV6", 
+    connector:Enum = Connector.Automatic.value,
     variable_references = [], 
     show_visualnames:bool = False
     )->pd.DataFrame: 
-        """Lists the current values of the selected zenon variables from Runtime. 
+        """Lists the current values of the selected variables from Service Engine. 
         
         'project_reference' and at least one 'variable_references' must be set.
 
@@ -666,8 +755,8 @@ class Server:
             Reference of the project from which the variable values should be read.
             To get the project reference use the function 'read_MetaData_Projects'.
         
-        connector: `string`
-            zenon Connectors: 'zenonV6' or 'zenonSQL'
+        connector: `Enum`
+            zenon Connectors: 'ServiceEngine', 'SQL', 'ServiceGridDataStorage', 'Automatic'
 
         variable_references: `list`
             Filter for variable references. 
@@ -696,6 +785,8 @@ class Server:
         >>> archive_data = zan.read_Online_Current_Variables_Value(project_name='ZAD_GBL', variable_reference=['Test_1', 'Test_2'])
         """
 
+        self._check_Connector(connector)
+
         variables = self._convert_list_To_String(variable_references)
         try:
             if not  show_visualnames:
@@ -722,12 +813,12 @@ class Server:
         except DatabaseError as ex:
            raise RuntimeError(ex)
         except :
-            raise RuntimeError("Unable to load current variable values from Runtime")
+            raise RuntimeError("Unable to load current variable values from Service Engine")
 
 
     def read_Online_Events(self, time_from:datetime, time_to:datetime, 
     project_reference:str = None, 
-    connector:str ="zenonV6", 
+    connector:Enum = Connector.Automatic.value,
     variable_references = [], 
     event_class_references = [],
     event_group_references = [],
@@ -736,7 +827,7 @@ class Server:
     include_System_Events:bool = False,
     show_visualnames:bool = False
     )->pd.DataFrame: 
-        """Lists all events of the selected project from Runtime. 
+        """Lists all events of the selected project from Service Engine. 
         
         'time_from', 'time_to' and 'project_reference' must be set.
 
@@ -754,8 +845,8 @@ class Server:
             Reference of the project from which the events should be read.
             To get the project reference use the function 'read_MetaData_Projects'.
 
-        connector: `string`
-            zenon Connectors: 'zenonV6' or 'zenonSQL'
+        connector: `Enum`
+            zenon Connectors: 'ServiceEngine', 'SQL', 'ServiceGridDataStorage', 'Automatic'
 
         variable_references: `list`
             Filter for variable references. 
@@ -816,6 +907,8 @@ class Server:
         >>> alarms = zan.read_Online_Events(time_from = time_from, time_to = time_to,project_reference='ZAD_GBL', include_System_Events = True)
         """
         
+        self._check_Connector(connector)
+
         variables = self._convert_list_To_String(variable_references)
         event_classes = self._convert_list_To_String(event_class_references)
         event_groups = self._convert_list_To_String(event_group_references)
@@ -871,12 +964,12 @@ class Server:
         except DatabaseError as ex:
            raise RuntimeError(ex)
         except :
-            raise RuntimeError("Unable to load events from Runtime")
+            raise RuntimeError("Unable to load events from Service Engine")
 
 
     def _read_Online_Lots(self, time_from:datetime, time_to:datetime,  
     project_reference:str, 
-    connector:str = "zenonV6", 
+    connector:Enum = Connector.Automatic.value,
     archive_reference:str = "")->pd.DataFrame:
         """Lists the lot information of the selected project.
         Parameters
@@ -891,8 +984,8 @@ class Server:
             Reference of the project from which the lot archive should be returned.
             To get the project reference use the function 'read_MetaData_Projects'.
 
-        connector: `string`
-            zenon Connectors: 'zenonV6' or 'zenonSQL'
+        connector: `Enum`
+            zenon Connectors: 'ServiceEngine', 'SQL', 'ServiceGridDataStorage', 'Automatic'
         
         archive_reference: `string`
             Archive reference of the lot archive.
@@ -902,7 +995,8 @@ class Server:
         --------
         DataFrame: [LOT, START, END]
         """        
-        
+        self._check_Connector(connector)
+
         sqlCmd = f"""SELECT *FROM [{self._metadb}].[dbo].[zrsQueryLotFunction](
                     '{self._metadb}'
                     ,'{project_reference}'
@@ -943,7 +1037,7 @@ class Server:
         """        
 
         if archive_references == None:
-            archives = self.read_MetaData_Archives()
+            archives = self.read_Metadata_ArchivesInProjects(project_references=[project_reference])
             refs = archives[archives.LOTARCHIV==True].REFERENCE
         else:
             refs = archive_references
@@ -984,7 +1078,7 @@ class Server:
 
     def read_Online_Shift(self, time_from:datetime, time_to:datetime,  
     project_reference:str, 
-    connector:str = "zenonSQL", 
+    connector:Enum = Connector.Automatic.value,
     equipment_group_reference:str = "",
     include_Pause:bool = True
     )->pd.DataFrame:
@@ -1001,8 +1095,8 @@ class Server:
             Reference of the project from which the shift information should be read.
             To get the project reference use the function 'read_MetaData_Projects'.
 
-        connector: `string`
-            zenon Connectors: 'zenonV6' or 'zenonSQL'
+        connector: `Enum`
+            zenon Connectors: 'ServiceEngine', 'SQL', 'ServiceGridDataStorage', 'Automatic'
         
         equipment_group_reference: `string`
             Equipment group reference of the shift.
@@ -1017,7 +1111,9 @@ class Server:
         --------
         DataFrame: [ ID, SHIFT, START, END, BREAK, PAREND_ID]
         """       
-        
+
+        self._check_Connector(connector)
+
         with_pause = self._convert_bool_To_String(include_Pause)
 
         sqlCmd = f"""SELECT *FROM [{self._metadb}].[dbo].[zrsQueryShiftFunction](
@@ -1034,7 +1130,7 @@ class Server:
            raise RuntimeError("Unable to load shift information from table")
 
 
-    def read_Online_ContextList(self, project_reference:str, connector:str = "zenonV6")->pd.DataFrame:
+    def read_Online_ContextList(self, project_reference:str, connector:Enum = Connector.Automatic.value)->pd.DataFrame:
         """Lists context list (Alarm causes) of the selected project.
         Parameters
         ---------
@@ -1042,13 +1138,15 @@ class Server:
             Reference of the project from which the context list should be read.
             To get the project reference use the function 'read_MetaData_Projects'.
 
-        connector: `string`
-            zenon Connectors: 'zenonV6' or 'zenonSQL'
+        connector: `Enum`
+            zenon Connectors: 'ServiceEngine', 'SQL', 'ServiceGridDataStorage', 'Automatic'
 
         Returns
         --------
         DataFrame: [ID, NAME, DESCRIPTION, REMOVED, PARENT_ID]
         """        
+
+        self._check_Connector(connector)
         
         sqlCmd = f"""SELECT *FROM [{self._metadb}].[dbo].[zrsQueryTextListFunction](
                     '{self._metadb}'
@@ -1071,4 +1169,8 @@ class Server:
         if not value:
             return "0"
         else:
-            return "1"
\ No newline at end of file
+            return "1"
+
+    def _check_Connector(self, connector:Connector):
+        if(self._analyzer_major_version < 11 and (connector == Connector.Automatic.value or connector == Connector.DataStorage.value)):
+            raise RuntimeError("The Automatic and ServiceGridDataStorage connectors require a Report Engine with the version 11 or higher")  
\ No newline at end of file
